@@ -55,9 +55,10 @@ def agency_id(self, agency):
     return None if agency.agency is None else 'ark:/' + agency.agency.ark
 
 
-SEDAArchiveTransferIClonableAdapter.__select__ &= is_in_state('published')
-SEDAArchiveTransferIClonableAdapter.rtype = 'new_version_of'
-SEDAArchiveTransferIClonableAdapter.skiprtypes += ('clone_of', 'used', 'generated')
+class SAEMSEDAArchiveTransferIClonableAdapter(SEDAArchiveTransferIClonableAdapter):
+    __select__ = SEDAArchiveTransferIClonableAdapter.__select__ & is_in_state('published')
+    rtype = 'new_version_of'
+    skiprtypes = SEDAArchiveTransferIClonableAdapter.skiprtypes + ('clone_of', 'used', 'generated')
 
 
 class SEDAArchiveTransfer(SEDAArchiveTransfer):
@@ -174,3 +175,10 @@ class OAISEDA1RNGExportView(OAISEDAExportView):
 
 class OAISEDA2RNGExportView(OAISEDAExportView):
     __regid__ = 'saem.oai.seda.2.0-rng'
+
+
+def registration_callback(vreg):
+    vreg.register_and_replace(SAEMSEDAArchiveTransferIClonableAdapter,
+                              SEDAArchiveTransferIClonableAdapter)
+    vreg.register_all(globals().values(), __name__,
+                      butclasses=(SAEMSEDAArchiveTransferIClonableAdapter,))
