@@ -36,6 +36,7 @@ from cubes.skos.hooks import ReplaceExternalUriByEntityHook
 # be logged nor impact container's modification date
 IGNORE_RELATIONS = set(('used', 'generated', 'associated_with',
                         'primary_email',
+                        'container',
                         'use_authorityrecord', 'related_concept_scheme', 'use_profile',
                         'new_version_of', 'clone_of',
                         'scheme_entity_type', 'scheme_relation_type'))
@@ -110,6 +111,10 @@ def _log_relation(rtype, entity, target):
     `entity` as the potentiel activity holder and `target` the other relation's
     end.
     """
+    # code_keyword_type is qualifying the subject scheme, don't log the
+    # modification on the target concept
+    if rtype == 'code_keyword_type':
+        return entity.cw_etype == 'ConceptScheme'
     # if entity is a scheme or concept, only log if the other ends is also a
     # concept or scheme
     if entity.cw_etype in ('Concept', 'ConceptScheme'):
@@ -216,7 +221,7 @@ def set_ark_and_cwuri(cw, eid, etype, entity_attrs, naa_what=None):
             if naa_what is None:
                 msg = _('an ARK identifier has to be generated but no Name Assigning Authority is '
                         'specified')
-                raise ValidationError(None, {'': msg})
+                raise ValidationError(None, {None: msg})
             generator = cw.vreg['adapters'].select('IARKGenerator', cw, eid=eid, etype=etype,
                                                    naa_what=naa_what)
             ark = generator.generate_ark()
