@@ -116,13 +116,25 @@ ImportSkosData.cw_store_factories['nohook'] = _nohook_store_factory
 # override seda's scheme initialization to set ark on each scheme, and to use an ark enabled store
 
 @monkeypatch(seda_dataimport)
-def init_seda_scheme(cnx, title, _count=[0]):
+def init_seda_scheme(cnx, title, _count=[]):
     description = u'edition 2009' if title.startswith('SEDA :') else None
     # 25651 = Archives départementales de la Gironde (ADGIRONDE)
     # XXX ensure that:
     # * NAA for those vocabulary is 25651
     # * generated ark are identical from one instance to another (for scheme and concepts, see
     #   below)
+
+    if not _count:
+        rset = cnx.execute(
+            'String ARK ORDERBY CD DESC LIMIT 1'
+            ' WHERE X creation_date CD, X ark LIKE "25651/v%", X ark ARK'
+        )
+        if not rset:
+            value = 0
+        else:
+            value = int(rset[0][0][len('25651/v'):])
+        _count.append(value)
+
     _count[0] += 1
     ark = u'25651/v%s' % _count[0]
     if cnx.vreg.config.repairing:  # XXX seda 0.8 migration
@@ -176,49 +188,6 @@ def negotiated_language(self):
 # temporary monkey-patches #########################################################################
 ####################################################################################################
 
-# proper behaviour of hooks control cm (https://www.cubicweb.org/ticket/17049333)
-
-from cubicweb.server import session  # noqa
-
-
-@monkeypatch(session)
-class _hooks_control(object):
-    def __init__(self, cnx, mode, *categories):
-        assert mode in (session.HOOKS_ALLOW_ALL, session.HOOKS_DENY_ALL)
-        self.cnx = cnx
-        self.mode = mode
-        self.categories = set(categories)
-        self.old_mode = None
-        self.old_categories = None
-
-    def __enter__(self):
-        self.old_mode = self.cnx._hooks_mode
-        self.old_categories = self.cnx._hooks_categories
-        self.cnx._hooks_mode = self.mode
-        self.cnx._hooks_categories = self.categories
-
-    def __exit__(self, exctype, exc, traceback):
-        self.cnx._hooks_mode = self.old_mode
-        self.cnx._hooks_categories = self.old_categories
-
-
-orig_connection_init = session.Connection.__init__
-
-
-@monkeypatch(session.Connection)
-def __init__(self, *args, **kwargs):
-    orig_connection_init(self, *args, **kwargs)
-    self._hooks_mode = session.HOOKS_ALLOW_ALL
-    self._hooks_categories = set()
-
-
-@monkeypatch(session.Connection)
-def is_hook_category_activated(self, category):
-    if self._hooks_mode is session.HOOKS_DENY_ALL:
-        return category in self._hooks_categories
-    return category not in self._hooks_categories
-
-
 # avoid disappearance of navtop components (https://www.cubicweb.org/17074195)
 # other part lies in views/patches.py
 
