@@ -15,7 +15,6 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 """cubicweb-saem-ref views/forms/actions/components for web ui"""
 
-from copy import deepcopy
 from functools import wraps
 
 from logilab.common.decorators import monkeypatch
@@ -55,17 +54,6 @@ abaa.tag_subject_of(('*', 'phone_number', '*'), False)
 affk.set_field_kwargs('*', 'ark', widget=fw.TextInput({'size': 80}), required=False)
 
 
-def selectable_uicfg(rtag, modname, select):
-    """Return a copy of uicfg `rtag` with `select` set.
-
-    Usually `modname` should be set to ``__name__`` from the caller.
-    """
-    copy = deepcopy(rtag)
-    copy.__module__ = modname
-    copy.__select__ = select
-    return copy
-
-
 def external_link(text, href):
     """Return an HTML link with an icon indicating that the URL is external.
     """
@@ -416,6 +404,7 @@ class SAEMRefRewriter(urlrewrite.SimpleReqRewriter):
     rules = [
         ('/oai', dict(vid='oai')),
         ('/ark', dict(vid='saem.ws.ark')),
+        ('/archival-units', dict(vid='saem.ws.archival-units')),
         ('/sedalib', dict(rql='Any X WHERE X is SEDAArchiveUnit, '
                               'NOT X seda_archive_unit P',
                           vid='saem.sedalib')),
