@@ -42,10 +42,6 @@ afs = uicfg.autoform_section
 aff = uicfg.autoform_field
 affk = uicfg.autoform_field_kwargs
 
-# XXX drop these two lines one eac > 0.5.0 is released
-afs.tag_object_of(('AgentPlace', 'place_address', 'PostalAddress'), 'main', 'hidden')
-afs.tag_object_of(('*', 'has_citation', '*'), 'main', 'hidden')
-
 for etype in ('AuthorityRecord',
               'AssociationRelation', 'ChronologicalRelation', 'HierarchicalRelation',
               'Mandate', 'LegalStatus', 'EACResourceRelation'):
@@ -157,8 +153,6 @@ def get_record_names(form, field):
 
 affk.set_field_kwargs('NameEntry', 'parts',
                       widget=TextInputCheckSimilar({'size': 80}, data_initfunc=get_record_names))
-# XXX can be removed once we depend on eac > 0.3
-affk.set_field_kwargs('NameEntry', 'form_variant', value=u'authorized')
 
 
 # hide record_id for now
