@@ -23,7 +23,6 @@ from dateutil.parser import parse as parse_date
 from lxml import etree
 import pytz
 
-from cubicweb import __pkginfo__
 from cubicweb.devtools.testlib import CubicWebTC
 from cubicweb.pyramid.test import PyramidCWTest
 
@@ -33,8 +32,6 @@ from cubicweb_saem_ref import permanent_url
 
 import testutils
 
-CW_324 = __pkginfo__.numversion < (3, 25)
-
 EntityInfo = namedtuple('EntityInfo', ['ark', 'url', 'eid'])
 
 
@@ -105,19 +102,16 @@ class OAIComponentTC(CubicWebTC, OAITestMixin):
 
 
 def setup_organization_units(cnx):
-    """Create three agents (alice, bobby and draft), publish alice and bobby but not draft, and return
-    the (ark, url, eid) attributes of alice and bobby.
+    """Create two agents (alice and bobby) in published state and return their
+    (ark, url, eid) attributes.
     """
     alice = testutils.organization_unit(cnx, u'alice',
                                         archival_roles=[u'producer'])
     cnx.commit()
-    publish_entity(alice)
     bobby = testutils.organization_unit(cnx, u'bobby',
                                         archival_roles=[u'enquirer'])
     cnx.commit()
-    publish_entity(bobby)
-    testutils.organization_unit(cnx, u'draft', archival_roles=[u'enquirer'])
-    cnx.commit()
+
     return (
         EntityInfo(alice.ark, permanent_url(alice), alice.eid),
         EntityInfo(bobby.ark, permanent_url(bobby), bobby.eid),
@@ -173,14 +167,6 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
     _validate_xml = True
     _debug_xml = False
 
-    if CW_324:
-        # webapp is initialized with https as url scheme, which trigger usage of https-url instead
-        # of base-url in 3.24, but tests below rely in base-url being used.
-        @classmethod
-        def init_config(cls, config):
-            super(PyramidCWTest, cls).init_config(config)
-            config.global_set_option('https-url', config['base-url'])
-
     def oai_request(self, req, **formparams):
         response = self.webapp.get('/oai', formparams)
         self.assertEqual(response.headers['Content-Type'], 'text/xml; charset=UTF-8')
@@ -277,8 +263,6 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
                                       metadataPrefix='rdf')
             self.assertIn('<identifier>ark:/{0}</identifier>'.format(bobby), result)
             self.assertIn('<identifier>ark:/{0}</identifier>'.format(alice), result)
-            draft = req.execute('Any A WHERE X ark A, X name "draft"')[0][0]
-            self.assertNotIn(draft, result)
             result = self.oai_request(req, verb='ListIdentifiers',
                                       set='organizationunit:role:producer',
                                       metadataPrefix='rdf')
@@ -298,20 +282,6 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
                                       set='profile', metadataPrefix='seda02xsd')
             self.assertIn('<identifier>ark:/{0}</identifier>'.format(profile.ark), result)
 
-    def test_listidentifiers_setspec_wfstate(self):
-        """Check workflow state condition is statisfied with a multi-level
-        setspec `organizationunit:role:enquirer`.
-        """
-        alice, bobby = [x.ark for x in self._setup_organization_units()]
-        self._setup_profile()
-        with self.admin_access.web_request() as req:
-            result = self.oai_request(req, verb='ListIdentifiers',
-                                      set='organizationunit:role:enquirer',
-                                      metadataPrefix='rdf')
-            self.assertIn('<identifier>ark:/{0}</identifier>'.format(bobby), result)
-            draft = req.execute('Any A WHERE X ark A, X name "draft"')[0][0]
-            self.assertNotIn(draft, result)
-
     def test_listidentifiers_deleted(self):
         """Check <header> element (status attribute, datestamp) for deleted
         records in ListIdentifiers response.
@@ -349,8 +319,6 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
                 '<rdf:Description rdf:about="{0}">'.format(bobby.url), result)
             self.assertIn(
                 '<rdf:Description rdf:about="{0}">'.format(alice.url), result)
-            draft = req.execute('Any A WHERE X ark A, X name "draft"')[0][0]
-            self.assertNotIn(draft, result)
             result = self.oai_request(
                 req, verb='ListRecords', set='organizationunit:role:producer',
                 metadataPrefix='rdf')
@@ -419,7 +387,6 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
         with self.admin_access.repo_cnx() as cnx:
             agent = testutils.agent(cnx, u'toto')
             cnx.commit()
-            publish_entity(agent)
             ark = agent.ark
         with self.admin_access.web_request() as req:
             result = self.oai_request(req, verb='GetRecord',
@@ -449,7 +416,6 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
         with self.admin_access.repo_cnx() as cnx:
             orgu = testutils.organization_unit(cnx, u'toto')
             cnx.commit()
-            publish_entity(orgu)
             ark = orgu.ark
         with self.admin_access.web_request() as req:
             result = self.oai_request(req, verb='GetRecord',
@@ -497,15 +463,6 @@ class OAIPMHViewsTC(PyramidCWTest, OAITestMixin, testutils.XmlTestMixin):
                 metadataPrefix='eac')
             self.assertIn('<identifier>ark:/' + ark, result)
 
-    def test_getrecord_draft(self):
-        self._setup_organization_units()
-        with self.admin_access.web_request() as req:
-            draft = req.execute('Any A WHERE X ark A, X name "draft"')[0][0]
-            result = self.oai_request(req, verb='GetRecord',
-                                      identifier='ark:/' + draft,
-                                      metadataPrefix='rdf')
-            self.assertIn('idDoesNotExist', result)
-
 
 if __name__ == '__main__':
     import unittest
