@@ -102,10 +102,12 @@ class FuncViewsTC(CubicWebTC):
     def test_eac_import_user_has_no_naa(self):
         regid = 'eac.import'
         with self.admin_access.web_request() as req:
+            req._ = lambda x: x + u' \xe9'
             output = self.view(regid, req=req, template=None)
             self.assertIn('be in an organization', output)
             self.assertIn('to access this functionnality', output)
         with self.admin_access.web_request() as req:
+            req._ = lambda x: x + u' \xe9'
             authority = req.cnx.create_entity('Organization', name=u'dummy',
                                               ark=u'123')
             req.user.cw_set(authority=authority)
@@ -233,6 +235,11 @@ class FuncViewsTC(CubicWebTC):
                               'vid': vid,
                               'rql': u'Any X WHERE X eid {}'.format(ou.eid)})
 
+    def test_email_address(self):
+        with self.admin_access.cnx() as cnx:
+            address = cnx.create_entity('EmailAddress', address=u'admin@cubicweb.org')
+            self.assertEqual(address.dc_title(), u'admin@cubicweb.org')
+
 
 class SEDAViewsTC(CubicWebTC):
 
@@ -476,6 +483,89 @@ class AssignArkWebServiceTC(CubicWebTC):
                              [{'ark': '0/a000000002'}])
 
 
+class ListArchivalUnitsServiceTC(CubicWebTC):
+    maxDiff = None
+
+    def test_ok(self):
+        with self.admin_access.cnx() as cnx:
+            org = testutils.authority_with_naa(cnx)
+            archival_unit = testutils.organization_unit(
+                cnx, u'Archival Dptmt', ['archival'],
+                reverse_archival_unit=org,
+                authority=org)
+            dep_unit = testutils.organization_unit(
+                cnx, u'Deposit Dptmt', ['deposit'],
+                authority=org)
+            deprecated_dep_unit = testutils.organization_unit(
+                cnx, u'Deprecated Deposit Dptmt', ['deposit'],
+                authority=org)
+            testutils.organization_unit(
+                cnx, u'Production Dptmt', ['producer'],
+                authority=org)
+            org2 = testutils.authority_with_naa(cnx, name=u'Another authority',
+                                                archival_unit=archival_unit)
+            dep2_unit = testutils.organization_unit(
+                cnx, u'Org 2 Deposit Dptmt', ['deposit'],
+                authority=org2)
+            cnx.commit()
+            deprecated_dep_unit.cw_adapt_to('IWorkflowable').fire_transition('deprecate')
+            cnx.commit()
+            # preload attributes accessed in later connection
+            org.ark, org2.ark
+            archival_unit.ark, dep_unit.ark, deprecated_dep_unit.ark, dep2_unit.ark
+
+        with self.admin_access.web_request(
+                headers={'Accept': 'application/json'}) as req:
+            result = json.loads(self.app_handle_request(req, 'archival-units'))
+            result[0]['deposit-units'].sort()
+            self.assertEqual(
+                result,
+                [{'ark': archival_unit.ark,
+                  'name': 'Archival Dptmt',
+                  'state': 'published',
+                  'url': archival_unit.absolute_url(),
+                  'authority': {
+                      'ark': org.ark,
+                      'name': org.name,
+                      'url': org.absolute_url(),
+                  },
+                  'deposit-units': [
+                      {
+                          'ark': dep_unit.ark,
+                          'name': dep_unit.name,
+                          'state': 'published',
+                          'url': dep_unit.absolute_url(),
+                          'authority': {
+                              'ark': org.ark,
+                              'name': org.name,
+                              'url': org.absolute_url(),
+                          },
+                      },
+                      {
+                          'ark': deprecated_dep_unit.ark,
+                          'name': deprecated_dep_unit.name,
+                          'state': 'deprecated',
+                          'url': deprecated_dep_unit.absolute_url(),
+                          'authority': {
+                              'ark': org.ark,
+                              'name': org.name,
+                              'url': org.absolute_url(),
+                          },
+                      },
+                      {
+                          'ark': dep2_unit.ark,
+                          'name': dep2_unit.name,
+                          'state': 'published',
+                          'url': dep2_unit.absolute_url(),
+                          'authority': {
+                              'ark': org2.ark,
+                              'name': org2.name,
+                              'url': org2.absolute_url(),
+                          },
+                      },
+                  ]}])
+
+
 class TimelineViewsTC(CubicWebTC):
 
     def test_timeline_json(self):
