@@ -56,6 +56,7 @@ class SAEMRefHooksTC(CubicWebTC):
         with self.admin_access.repo_cnx() as cnx:
             scheme = cnx.create_entity('ConceptScheme', title=u'my thesaurus',
                                        ark_naa=testutils.naa(cnx))
+            kt_scheme = testutils.scheme_for_type(cnx, 'seda_keyword_type_to', None, u'theme')
             cnx.commit()
             self.resetMD(cnx, scheme)
             c1 = scheme.add_concept(u'concept 1', language_code=u'fr')
@@ -88,6 +89,15 @@ class SAEMRefHooksTC(CubicWebTC):
             self.assertMDNow(c1)
             self.assertMDNow(scheme)
 
+            self.resetMD(cnx, scheme)
+            self.resetMD(cnx, kt_scheme)
+            cnx.commit()
+            scheme.cw_set(code_keyword_type=kt_scheme.reverse_in_scheme[0])
+            cnx.commit()
+            kt_scheme.cw_clear_all_caches()
+            self.assertEqual(kt_scheme.modification_date, YESTERDAY)
+            self.assertMDNow(scheme)
+
     def test_sync_profile_md(self):
         with self.admin_access.repo_cnx() as cnx:
             scheme = testutils.scheme_for_type(cnx, 'seda_rule', 'SEDASeqAccessRuleRule', u'AR038')
