@@ -48,9 +48,10 @@ class SchemaConstraintsTC(CubicWebTC):
         """
         with self.admin_access.repo_cnx() as cnx:
             peter = testutils.agent(cnx, u'Peter')
-            testutils.agent(cnx, u'Norton')
+            norton = testutils.agent(cnx, u'Norton')
+            cnx.commit()
+            norton.cw_adapt_to('IWorkflowable').fire_transition('deprecate')
             cnx.commit()
-            peter.cw_adapt_to('IWorkflowable').fire_transition('publish')
             ou = testutils.organization_unit(cnx, u'Alice')
             cnx.commit()
             rset = ou.unrelated('contact_point', 'Agent')
@@ -63,9 +64,9 @@ class SchemaConstraintsTC(CubicWebTC):
         """
         with self.admin_access.repo_cnx() as cnx:
             pou = testutils.organization_unit(cnx, u'P OU', archival_roles=['archival'])
-            testutils.organization_unit(cnx, u'N OU', archival_roles=['archival'])
+            nou = testutils.organization_unit(cnx, u'N OU', archival_roles=['archival'])
             cnx.commit()
-            pou.cw_adapt_to('IWorkflowable').fire_transition('publish')
+            nou.cw_adapt_to('IWorkflowable').fire_transition('deprecate')
             cnx.commit()
             # should be created by testutils.organization_unit() above.
             authority = cnx.find('Organization', name=u'Default authority').one()
@@ -150,14 +151,10 @@ class SchemaConstraintsTC(CubicWebTC):
         with self.admin_access.repo_cnx() as cnx:
             # Create an archival agent in a custom authority
             authority = testutils.authority_with_naa(cnx, name=u'boss club')
-            jdoe = testutils.agent(cnx, u'jdoe', authority=authority)
+            testutils.agent(cnx, u'jdoe', authority=authority)
             # Create another archival agent in the default authority
             norton = testutils.agent(cnx, u'Norton')
             cnx.commit()
-            # Publish both agents (because of the published constraint)
-            jdoe.cw_adapt_to('IWorkflowable').fire_transition('publish')
-            norton.cw_adapt_to('IWorkflowable').fire_transition('publish')
-            cnx.commit()
             # Now create an organisation unit and check the unrelated list
             ou = testutils.organization_unit(cnx, u'Alice')
             cnx.commit()
@@ -171,13 +168,9 @@ class SchemaConstraintsTC(CubicWebTC):
         with self.admin_access.repo_cnx() as cnx:
             # Create an organization unit in a custom authority
             authority = testutils.authority_with_naa(cnx, name=u'boss club')
-            jdoe = testutils.organization_unit(cnx, u'jdoe', archival_roles=['archival'])
+            testutils.organization_unit(cnx, u'jdoe', archival_roles=['archival'])
             # Create another archival organization unit in the default authority
-            norton = testutils.organization_unit(cnx, u'Norton', archival_roles=[u'archival'])
-            cnx.commit()
-            # Publish both organization units (because of the published constraint)
-            jdoe.cw_adapt_to('IWorkflowable').fire_transition('publish')
-            norton.cw_adapt_to('IWorkflowable').fire_transition('publish')
+            testutils.organization_unit(cnx, u'Norton', archival_roles=[u'archival'])
             cnx.commit()
             # Now check the unrelated list for authority's archival_unit
             authority = cnx.find('Organization', name=u'Default authority').one()
